compatibility library

Additional API to be used when migrating existing code to ngx_test.

It is highly recommended not to use this and only stick to ngx_test.dart for any new code or for new users of this package. APIs may change at any time without adhering strictly to sem-ver.

Functions

injectFromFixture<T>(NgTestFixture<void> fixture, Object tokenOrType) → T
Inject a service for tokenOrType from fixture.